@@ -16,9 +16,16 @@ except ImportError:
     _matplotlib_available = False
     print("You should install matplotlib to draw Bode plot")
 
-__version__ = (0, 4, 0)
+__version__ = (0, 4, 1)
 __author__ = "Fabrice Sincère <fabrice.sincere@ac-grenoble.fr>"
 
+"""Release History
+0.4.1 : add DEFAULT_FREQUENCY
+0.4.0 : first publication to pypi (2020-05)
+[...]
+0.0.1 : initial release (2018-10)
+"""
+
 if sys.version_info[0] < 3:
     print('You need to run this with Python 3')
     exit(1)
@@ -43,6 +50,51 @@ prefix is one of :
     return significand * prefixes[prefix]
 
 
+def EngineeringNotation(value):
+    """value -> float
+
+Return a tuple (significand, prefix)
+with significand between 1 and 1000
+
+significand -> float
+prefix  -> str
+
+prefix is one of :
+'p' pico, 'n', 'u' or 'µ' micro, 'm', 'k', 'M' mega, 'G', 'T', '' default
+
+>>> from acelectricity import *
+>>> EngineeringNotation(999)    #  (999, '')
+>>> EngineeringNotation(1000)   #  (1.0, 'k')
+>>> EngineeringNotation(-1e-6)  #  (-1.0, 'µ')
+>>> EngineeringNotation(0)      #  (0, '')
+"""
+    if value == 0.0:
+        return (0, '')
+
+    nbdecimal = math.log10(abs(value))
+
+    if -15.0 <= nbdecimal < -9.0:
+        return (value*1e12, 'p')
+    elif -9.0 <= nbdecimal < -6.0:
+        return (value*1e9, 'n')
+    elif -6.0 <= nbdecimal < -3.0:
+        return (value*1e6, 'µ')
+    elif -3.0 <= nbdecimal < 0.0:
+        return (value*1e3, 'm')
+    elif 0.0 <= nbdecimal < 3.0:
+        return (value, '')
+    elif 3.0 <= nbdecimal < 6.0:
+        return (value*1e-3, 'k')
+    elif 6.0 <= nbdecimal < 9.0:
+        return (value*1e-6, 'M')
+    elif 9.0 <= nbdecimal < 12.0:
+        return (value*1e-9, 'G')
+    elif 12.0 <= nbdecimal < 15.0:
+        return (value*1e-12, 'T')
+    else:
+        return (value, '')  # scientific notation
+
+
 def getfrequency(value, unit):
     """return tuple (frequency, angular frequency)
 value : positive float
@@ -337,8 +389,7 @@ return parallel inductance Lp (henry) if defines"""
     def bode(self, xmin=10, xmax=100000, xunit='Hz', n=1000,
              xscale='log', yscale='linear',
              magnitude_label='Magnitude',
-             phase_unit='degrees',
-             title='Bode plot'):
+             phase_unit='degrees', title='Bode plot'):
         """Draw Bode plot
 xunit = prefix + ['Hz' | 'rad/s']
 n = number of points (int)
@@ -562,8 +613,9 @@ Equiv. parallel inductance (H) : {}
         return self.__str__()
 
     def __str__(self):
-        return "Complex impedance (Ω) : {:g} \
-@ 1 kHz".format(self(value=1000, unit='Hz'))
+        return "Complex impedance (Ω) : {:g} @ {} {}Hz".format(
+            self(value=ElectricalQuantity.DEFAULT_FREQUENCY, unit='Hz'),
+            *EngineeringNotation(ElectricalQuantity.DEFAULT_FREQUENCY))
 
     def __add__(self, impedance):
         """self.__add__(impedance) <=> self + impedance
@@ -815,8 +867,9 @@ Equiv. series inductance (H) : {}
         return self.__str__()
 
     def __str__(self):
-        return "Complex admittance (S) : \
-{:g} @ 1 kHz".format(self(value=1000, unit='Hz'))
+        return "Complex admittance (S) : {:g} @ {} {}Hz".format(
+            self(value=ElectricalQuantity.DEFAULT_FREQUENCY, unit='Hz'),
+            *EngineeringNotation(ElectricalQuantity.DEFAULT_FREQUENCY))
 
     def __add__(self, admittance):
         "self.__add__(admittance) <=> self + admittance"
@@ -1265,14 +1318,17 @@ return complex Power
 class ElectricalQuantity:
     """ElectricalQuantity serves as a base class for Voltage, Current,
 Power and Ratio classes"""
+
+    # class attribut
+    DEFAULT_FREQUENCY = 1000  # Hz
+
     def __init__(self):
         pass
 
     def bode(self, xmin=10, xmax=100000, xunit='Hz', n=1000,
              xscale='log', yscale='linear',
              magnitude_label='Magnitude', magnitude_unit='db',
-             phase_unit='degrees',
-             title='Bode plot'):
+             phase_unit='degrees', title='Bode plot'):
         """Draw Bode plot
 xunit = prefix + ['Hz' | 'rad/s']
 n = number of points (int)
@@ -1359,9 +1415,11 @@ phase_unit= ["degrees" | 'radians']
         ax2 = ax1.twinx()
 
         if magnitude_unit == 'db':
-            ax1.set_ylabel('{} [{}]'.format(magnitude_label, self.db_unit), color='b')
+            ax1.set_ylabel('{} [{}]'.format(
+                magnitude_label, self.db_unit), color='b')
         elif magnitude_unit == 'default':
-            ax1.set_ylabel('{} [{}]'.format(magnitude_label, self.unit), color='b')
+            ax1.set_ylabel('{} [{}]'.format(
+                magnitude_label, self.unit), color='b')
 
         if xscale == 'log':
             if yscale == 'linear':
@@ -1527,8 +1585,9 @@ Phase (radians) : {:+g}
         return self.__str__()
 
     def __str__(self):
-        return "Ratio : {:g} \
-@ 1 kHz".format(self(value=1000, unit='Hz'))
+        return "Ratio : {:g} @ {} {}Hz".format(
+            self(value=ElectricalQuantity.DEFAULT_FREQUENCY, unit='Hz'),
+            *EngineeringNotation(ElectricalQuantity.DEFAULT_FREQUENCY))
 
     def __add__(self, arg):
         if isinstance(arg, Ratio) is True:
@@ -1798,8 +1857,9 @@ v(t) = {:g}×sin({:g}×t {:+f})
         return self.__str__()
 
     def __str__(self):
-        return "Complex voltage (Vrms) : {:g} \
-@ 1 kHz".format(self(value=1000, unit='Hz'))
+        return "Complex voltage (Vrms) : {:g} @ {} {}Hz".format(
+            self(value=ElectricalQuantity.DEFAULT_FREQUENCY, unit='Hz'),
+            *EngineeringNotation(ElectricalQuantity.DEFAULT_FREQUENCY))
 
     def __add__(self, voltage):
         """self.__add__(voltage) <=> self + voltage
@@ -2024,8 +2084,9 @@ i(t) = {:g}×sin({:g}×t {:+f})
         return self.__str__()
 
     def __str__(self):
-        return "Complex current (Arms) : {:g} \
-@ 1 kHz".format(self(value=1000, unit='Hz'))
+        return "Complex current (Arms) : {:g} @ {} {}Hz".format(
+            self(value=ElectricalQuantity.DEFAULT_FREQUENCY, unit='Hz'),
+            *EngineeringNotation(ElectricalQuantity.DEFAULT_FREQUENCY))
 
     def __add__(self, current):
         """self.__add__(current) <=> self + current
@@ -2236,8 +2297,9 @@ Active power (dBW ref 1 W) : {}
         return self.__str__()
 
     def __str__(self):
-        return "Complex power (W): {:g} \
-@ 1 kHz".format(self(value=1000, unit='Hz'))
+        return "Complex power (W): {:g} @ {} {}Hz".format(
+            self(value=ElectricalQuantity.DEFAULT_FREQUENCY, unit='Hz'),
+            *EngineeringNotation(ElectricalQuantity.DEFAULT_FREQUENCY))
 
     def __add__(self, power):
         """self.__add__(power) <=> self + power
